
#include "x509_asn1.h"

const static_asn pkcs1_asn1_tab[]={
  {"PKCS-1",536872976,0},
  {0,1610612748,0},
  {"iso",1073741825,"1"},
  {"member-body",1073741825,"2"},
  {"us",1073741825,"840"},
  {"rsadsi",1073741825,"113549"},
  {"pkcs",1073741825,"1"},
  {"pkcs-1",1073741825,"1"},
  {"modules",1073741825,"0"},
  {"pkcs-1",1,"1"},
  {"RSAPublicKey",1610612741,0},
  {"modulus",1073741827,0},
  {"publicExponent",3,0},
  {"RSAPrivateKey",1610612741,0},
  {"version",1073741826,"Version"},
  {"modulus",1073741827,0},
  {"publicExponent",1073741827,0},
  {"privateExponent",1073741827,0},
  {"prime1",1073741827,0},
  {"prime2",1073741827,0},
  {"exponent1",1073741827,0},
  {"exponent2",1073741827,0},
  {"coefficient",1073741827,0},
  {"otherPrimeInfos",16386,"OtherPrimeInfos"},
  {"Version",1610874883,0},
  {"two-prime",1073741825,"0"},
  {"multi",1,"1"},
  {"OtherPrimeInfos",1612709899,0},
  {"MAX",1074266122,"1"},
  {0,2,"OtherPrimeInfo"},
  {"OtherPrimeInfo",1610612741,0},
  {"prime",1073741827,0},
  {"exponent",1073741827,0},
  {"coefficient",3,0},
  {"AlgorithmIdentifier",1610612741,0},
  {"algorithm",1073741836,0},
  {"parameters",541081613,0},
  {"algorithm",1,0},
  {"DigestInfo",1610612741,0},
  {"digestAlgorithm",1073741826,"DigestAlgorithmIdentifier"},
  {"digest",2,"Digest"},
  {"DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
  {"Digest",7,0},
  {0,0,0}
};
